@@ -7,7 +7,7 @@ from pyramid.view import view_config
 
 LOG = logging.getLogger('zopyx.gridfs')
 
-@view_config(name='gridfs')
+@view_config(route_name='gridfs')
 def gridfs_view(request):
 
     settings = request.registry.settings
@@ -15,18 +15,14 @@ def gridfs_view(request):
     port = settings.get('mongodb_port', '27017')
     database = settings.get('mongodb_database', 'test')
 
-    if len(request.subpath) != 2:
-        return Response(status=404)
-
-    collection, filename = request.subpath
-
     try:
         conn = pymongo.Connection(host, int(port))
         LOG.debug('Connected to mongodb://%s:%s/%s'  % (host, port, database))
 
         db = getattr(conn, database)
-        fs = gridfs.GridFS(db, collection)
+        fs = gridfs.GridFS(db, request.matchdict['collection'])
 
+        filename = request.matchdict['filename']
         if not fs.exists(filename):
             return Response(status=404)
 
